@@ -6,20 +6,35 @@
     a single BED; v) merge features within one or more BED files; vi) create a BED of 
     complementary features.
 
-    ******************
+    ##################
     Command-line Usage
-    ******************
+    ##################
     The BED utilites function may be called using the following command:
 
     .. code-block:: bash
         
         bed_utilities.py
 
-
     ########
     Utilites
     ########
 
+    ***************
+    Windows Utility
+    ***************
+
+    Given a chromosome size file and a window size, the windows utility will generate a 
+    BED file of interval features.
+
+    =============
+    Example usage
+    =============
+    Return a BED with interval features that do not extend outside the chromosomes:
+
+    .. code-block:: bash
+        
+        bed_utilities.py --utility windows --chrom-file hg18.chrom.sizes --window-size 1000 --out hg18_windows.bed
+
     **************
     Sample Utility
     **************
@@ -116,6 +131,22 @@
         
         bed_utilities.py --utility complement --bed examples/files/chr1_sites.bed --chrom-file examples/files/chr_sizes.txt
 
+    *****************
+    Intersect Utility
+    *****************
+
+    Given a BED file and an intersect file, return only the interval features within the BED
+    file that overlap with the intersect file. 
+
+    =============
+    Example usage
+    =============
+    Return a BED with only intersecting interval features:
+
+    .. code-block:: bash
+        
+        bed_utilities.py --utility intersect --bed hg18_windows.bed --intersect-file Intersect.vcf.gz --out hg18_intersects.bed
+
     *************
     Merge Utility
     *************
@@ -163,7 +194,10 @@
             chrX\t154913754
             chrY\t57772954
 
-        Appropriate files may be downloaded from the UCSC Genome Browser.
+        Appropriate files may be downloaded from the `UCSC Genome Browser <http://hgdownload.soe.ucsc.edu/downloads.html>`_. 
+        The supported **ASSEMBLY.chrom.sizes** file for each assembly may be found by 
+        clicking **Genome sequence files and select annotations** (followed by
+        **Standard genome sequence files and select annotations** on select assemblies).
     
     #############################
     Output Command-line Arguments
@@ -185,6 +219,12 @@
         files (merge); create a BED file of complementary features - i.e. features that 
         do not overlap - from a BED file (complement).
 
+    *************************************
+    Window Utility Command-line Arguments
+    *************************************
+    **--window-size** *<window_size_int>*
+        Argument used to define the window/interval size to return.
+
     *************************************
     Sample Utility Command-line Arguments
     *************************************
@@ -228,6 +268,14 @@
         Argument used to define the length of base pairs (bp) to extend downstream of 
         features.
 
+    ****************************************
+    Intersect Utility Command-line Arguments
+    ****************************************
+    **--intersect-file** *<intersect_file_filename>*
+        Argument used to define the BED/VCF/VCF.gz file used to remove features that 
+        do not intersect with the given file's features/variants.
+        removing features/positions.
+
     ************************************
     Merge Utility Command-line Arguments
     ************************************
